==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkOpenGLPolyDataMapper.java <==
// java wrapper for vtkOpenGLPolyDataMapper object
//

package vtk;
import vtk.*;

public class vtkOpenGLPolyDataMapper extends vtkPolyDataMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RenderPiece_2(vtkRenderer id0,vtkActor id1);
  public void RenderPiece(vtkRenderer id0,vtkActor id1)
    { RenderPiece_2(id0,id1); }

  private native void RenderPieceStart_3(vtkRenderer id0,vtkActor id1);
  public void RenderPieceStart(vtkRenderer id0,vtkActor id1)
    { RenderPieceStart_3(id0,id1); }

  private native void RenderPieceDraw_4(vtkRenderer id0,vtkActor id1);
  public void RenderPieceDraw(vtkRenderer id0,vtkActor id1)
    { RenderPieceDraw_4(id0,id1); }

  private native void RenderPieceFinish_5(vtkRenderer id0,vtkActor id1);
  public void RenderPieceFinish(vtkRenderer id0,vtkActor id1)
    { RenderPieceFinish_5(id0,id1); }

  private native void ReleaseGraphicsResources_6(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_6(id0); }

  private native int GetPopulateSelectionSettings_7();
  public int GetPopulateSelectionSettings()
    { return GetPopulateSelectionSettings_7(); }

  private native void SetPopulateSelectionSettings_8(int id0);
  public void SetPopulateSelectionSettings(int id0)
    { SetPopulateSelectionSettings_8(id0); }

  private native boolean GetSupportsSelection_9();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_9(); }

  private native boolean GetIsOpaque_10();
  public boolean GetIsOpaque()
    { return GetIsOpaque_10(); }

  private native void SetPointIdArrayName_11(String id0);
  public void SetPointIdArrayName(String id0)
    { SetPointIdArrayName_11(id0); }

  private native String GetPointIdArrayName_12();
  public String GetPointIdArrayName()
    { return GetPointIdArrayName_12(); }

  private native void SetCellIdArrayName_13(String id0);
  public void SetCellIdArrayName(String id0)
    { SetCellIdArrayName_13(id0); }

  private native String GetCellIdArrayName_14();
  public String GetCellIdArrayName()
    { return GetCellIdArrayName_14(); }

  private native void SetProcessIdArrayName_15(String id0);
  public void SetProcessIdArrayName(String id0)
    { SetProcessIdArrayName_15(id0); }

  private native String GetProcessIdArrayName_16();
  public String GetProcessIdArrayName()
    { return GetProcessIdArrayName_16(); }

  private native void SetCompositeIdArrayName_17(String id0);
  public void SetCompositeIdArrayName(String id0)
    { SetCompositeIdArrayName_17(id0); }

  private native String GetCompositeIdArrayName_18();
  public String GetCompositeIdArrayName()
    { return GetCompositeIdArrayName_18(); }

  private native void AddShaderReplacement_19(int id0,String id1,boolean id2,String id3,boolean id4);
  public void AddShaderReplacement(int id0,String id1,boolean id2,String id3,boolean id4)
    { AddShaderReplacement_19(id0,id1,id2,id3,id4); }

  private native void ClearShaderReplacement_20(int id0,String id1,boolean id2);
  public void ClearShaderReplacement(int id0,String id1,boolean id2)
    { ClearShaderReplacement_20(id0,id1,id2); }

  private native void SetVertexShaderCode_21(String id0);
  public void SetVertexShaderCode(String id0)
    { SetVertexShaderCode_21(id0); }

  private native String GetVertexShaderCode_22();
  public String GetVertexShaderCode()
    { return GetVertexShaderCode_22(); }

  private native void SetFragmentShaderCode_23(String id0);
  public void SetFragmentShaderCode(String id0)
    { SetFragmentShaderCode_23(id0); }

  private native String GetFragmentShaderCode_24();
  public String GetFragmentShaderCode()
    { return GetFragmentShaderCode_24(); }

  private native void SetGeometryShaderCode_25(String id0);
  public void SetGeometryShaderCode(String id0)
    { SetGeometryShaderCode_25(id0); }

  private native String GetGeometryShaderCode_26();
  public String GetGeometryShaderCode()
    { return GetGeometryShaderCode_26(); }

  private native void ShallowCopy_27(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_27(id0); }

  private native void ForceHaveAppleBugOff_28();
  public void ForceHaveAppleBugOff()
    { ForceHaveAppleBugOff_28(); }

  private native void ForceHaveAppleBugOn_29();
  public void ForceHaveAppleBugOn()
    { ForceHaveAppleBugOn_29(); }

  private native boolean GetHaveAppleBug_30();
  public boolean GetHaveAppleBug()
    { return GetHaveAppleBug_30(); }

  private native long GetVBOs_31();
  public vtkOpenGLVertexBufferObjectGroup GetVBOs() {
    long temp = GetVBOs_31();

    if (temp == 0) return null;
    return (vtkOpenGLVertexBufferObjectGroup)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVBOShiftScaleMethod_32(int id0);
  public void SetVBOShiftScaleMethod(int id0)
    { SetVBOShiftScaleMethod_32(id0); }

  public vtkOpenGLPolyDataMapper() { super(); }

  public vtkOpenGLPolyDataMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-2-armv6h.pkg.tar.xz: vtk/vtkOpenGLPolyDataMapper.java <==
// java wrapper for vtkOpenGLPolyDataMapper object
//

package vtk;
import vtk.*;

public class vtkOpenGLPolyDataMapper extends vtkPolyDataMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RenderPiece_2(vtkRenderer id0,vtkActor id1);
  public void RenderPiece(vtkRenderer id0,vtkActor id1)
    { RenderPiece_2(id0,id1); }

  private native void RenderPieceStart_3(vtkRenderer id0,vtkActor id1);
  public void RenderPieceStart(vtkRenderer id0,vtkActor id1)
    { RenderPieceStart_3(id0,id1); }

  private native void RenderPieceDraw_4(vtkRenderer id0,vtkActor id1);
  public void RenderPieceDraw(vtkRenderer id0,vtkActor id1)
    { RenderPieceDraw_4(id0,id1); }

  private native void RenderPieceFinish_5(vtkRenderer id0,vtkActor id1);
  public void RenderPieceFinish(vtkRenderer id0,vtkActor id1)
    { RenderPieceFinish_5(id0,id1); }

  private native void ReleaseGraphicsResources_6(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_6(id0); }

  private native int GetPopulateSelectionSettings_7();
  public int GetPopulateSelectionSettings()
    { return GetPopulateSelectionSettings_7(); }

  private native void SetPopulateSelectionSettings_8(int id0);
  public void SetPopulateSelectionSettings(int id0)
    { SetPopulateSelectionSettings_8(id0); }

  private native boolean GetSupportsSelection_9();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_9(); }

  private native boolean GetIsOpaque_10();
  public boolean GetIsOpaque()
    { return GetIsOpaque_10(); }

  private native void SetPointIdArrayName_11(String id0);
  public void SetPointIdArrayName(String id0)
    { SetPointIdArrayName_11(id0); }

  private native String GetPointIdArrayName_12();
  public String GetPointIdArrayName()
    { return GetPointIdArrayName_12(); }

  private native void SetCellIdArrayName_13(String id0);
  public void SetCellIdArrayName(String id0)
    { SetCellIdArrayName_13(id0); }

  private native String GetCellIdArrayName_14();
  public String GetCellIdArrayName()
    { return GetCellIdArrayName_14(); }

  private native void SetProcessIdArrayName_15(String id0);
  public void SetProcessIdArrayName(String id0)
    { SetProcessIdArrayName_15(id0); }

  private native String GetProcessIdArrayName_16();
  public String GetProcessIdArrayName()
    { return GetProcessIdArrayName_16(); }

  private native void SetCompositeIdArrayName_17(String id0);
  public void SetCompositeIdArrayName(String id0)
    { SetCompositeIdArrayName_17(id0); }

  private native String GetCompositeIdArrayName_18();
  public String GetCompositeIdArrayName()
    { return GetCompositeIdArrayName_18(); }

  private native void AddShaderReplacement_19(int id0,String id1,boolean id2,String id3,boolean id4);
  public void AddShaderReplacement(int id0,String id1,boolean id2,String id3,boolean id4)
    { AddShaderReplacement_19(id0,id1,id2,id3,id4); }

  private native void ClearShaderReplacement_20(int id0,String id1,boolean id2);
  public void ClearShaderReplacement(int id0,String id1,boolean id2)
    { ClearShaderReplacement_20(id0,id1,id2); }

  private native void SetVertexShaderCode_21(String id0);
  public void SetVertexShaderCode(String id0)
    { SetVertexShaderCode_21(id0); }

  private native String GetVertexShaderCode_22();
  public String GetVertexShaderCode()
    { return GetVertexShaderCode_22(); }

  private native void SetFragmentShaderCode_23(String id0);
  public void SetFragmentShaderCode(String id0)
    { SetFragmentShaderCode_23(id0); }

  private native String GetFragmentShaderCode_24();
  public String GetFragmentShaderCode()
    { return GetFragmentShaderCode_24(); }

  private native void SetGeometryShaderCode_25(String id0);
  public void SetGeometryShaderCode(String id0)
    { SetGeometryShaderCode_25(id0); }

  private native String GetGeometryShaderCode_26();
  public String GetGeometryShaderCode()
    { return GetGeometryShaderCode_26(); }

  private native void ShallowCopy_27(vtkAbstractMapper id0);
  public void ShallowCopy(vtkAbstractMapper id0)
    { ShallowCopy_27(id0); }

  private native void ForceHaveAppleBugOff_28();
  public void ForceHaveAppleBugOff()
    { ForceHaveAppleBugOff_28(); }

  private native void ForceHaveAppleBugOn_29();
  public void ForceHaveAppleBugOn()
    { ForceHaveAppleBugOn_29(); }

  private native boolean GetHaveAppleBug_30();
  public boolean GetHaveAppleBug()
    { return GetHaveAppleBug_30(); }

  private native long GetVBOs_31();
  public vtkOpenGLVertexBufferObjectGroup GetVBOs() {
    long temp = GetVBOs_31();

    if (temp == 0) return null;
    return (vtkOpenGLVertexBufferObjectGroup)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetVBOShiftScaleMethod_32(int id0);
  public void SetVBOShiftScaleMethod(int id0)
    { SetVBOShiftScaleMethod_32(id0); }

  private native void MapDataArrayToVertexAttribute_33(String id0,String id1,int id2,int id3);
  public void MapDataArrayToVertexAttribute(String id0,String id1,int id2,int id3)
    { MapDataArrayToVertexAttribute_33(id0,id1,id2,id3); }

  private native void RemoveVertexAttributeMapping_34(String id0);
  public void RemoveVertexAttributeMapping(String id0)
    { RemoveVertexAttributeMapping_34(id0); }

  private native void RemoveAllVertexAttributeMappings_35();
  public void RemoveAllVertexAttributeMappings()
    { RemoveAllVertexAttributeMappings_35(); }

  public vtkOpenGLPolyDataMapper() { super(); }

  public vtkOpenGLPolyDataMapper(long id) { super(id); }
  public native long   VTKInit();

}
